/*
 * AddrBook.java	A simple address book.
 */
import java.io.*;
import java.util.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

public class AddrBook extends JFrame {

	AddrEntry	entry;

  public AddrBook()
  {
    super( "A Simple Address Book" );

    entry = new AddrEntry();
    initComponents();

    setSize( 500, 200 );
    setLocationRelativeTo( null );
    setDefaultCloseOperation( EXIT_ON_CLOSE );
  }

  public void initComponents()
  {
    // menus
    JMenuBar mb = new JMenuBar();
    setJMenuBar( mb );
    JMenu fileMenu, helpMenu;
    mb.add( (fileMenu = new JMenu("File")) );
    mb.add( (helpMenu = new JMenu("Help")) );

    // menu items
    JMenuItem miOpen, miAbout;
    fileMenu.add( (miOpen = new JMenuItem("Open")) );
    helpMenu.add( (miAbout = new JMenuItem("About")) );

    // address panel
    Container cp = getContentPane();
    cp.add( new AddressPanel(), BorderLayout.CENTER );

    // event handlers
    ActionEventHandler ah = new ActionEventHandler();
    miOpen.addActionListener( ah );
    miAbout.addActionListener( ah );
  }

  public void read()
  {
    try
    {
      BufferedReader br = new BufferedReader( new FileReader("addresses.txt") );
      String line;
      while( (line = br.readLine()) != null )
        if( line.trim().length() != 0 ) entry = new AddrEntry(line);
      br.close();
    }
    catch( Exception e )
    {
      System.err.println( "failed to read from addresses.txt." );
      e.printStackTrace();
    }
  }

  class ActionEventHandler implements ActionListener {

    public ActionEventHandler() {}

    public void actionPerformed( ActionEvent e )
    {
      String cmd = e.getActionCommand();

      if( cmd.equals("Open") ) read();

      else if( cmd.equals("About") )
        JOptionPane.showMessageDialog( null, "AddrBook - A Simple " +
          "Address Book" );
      else
        System.out.println( cmd + " is not implemented yet." );

      repaint();
    }

  } // end of class ActionEventHandler

  class AddressPanel extends JPanel {

	JButton		btnUpdate, btnNext;
	JTextField	tfFname, tfLname, tfPhone, tfEmail, tfAddress;

    public AddressPanel()
    {
      setLayout( new GridLayout(6,2) );
      add( new JLabel("First Name:") );
      add( tfFname = new JTextField() );      
      add( new JLabel("Last Name:") );
      add( tfLname = new JTextField() );      
      add( new JLabel("Phone:") );
      add( tfPhone = new JTextField() );      
      add( new JLabel("Email:") );
      add( tfEmail = new JTextField() );      
      add( new JLabel("Address:") );
      add( tfAddress = new JTextField() );      
      add( btnUpdate = new JButton("Update") );
      add( btnNext = new JButton("Next") );
    }

    public void setAddress()
    {
      tfFname.setText( entry.fname );
      tfLname.setText( entry.lname );
      tfPhone.setText( entry.phone );
      tfEmail.setText( entry.email );
      tfAddress.setText( entry.address );
    }

    public void paint( Graphics g )
    {
      super.paint(g);
      setAddress();
    }

  } // end of class AddressPanel
 
  public static void main( String args[] )
  {
    AddrBook a = new AddrBook();
    // f.setVisible( true );
    a.show();
  }

} // end of class AddrBook

